-- fendt31xSeries.lua
-- Script for Fendt Farmer 310/312 LSA
--
-- Author RivalBomb
-- 05.01.2016

fendt31xSeries = {};

function fendt31xSeries.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function fendt31xSeries:load(xmlFile)
	self.setWarningLight = SpecializationUtil.callSpecializationsFunction("setWarningLight");

	if self.isClient then
		self.sampleStartKlack = Utils.loadSample(xmlFile, {}, "vehicle.fendt31xDisplay.startKlackSound", "sounds/start_klack.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenDoorL = Utils.loadSample(xmlFile, {}, "vehicle.openDoorSound", "sounds/tuer_auf.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorL = Utils.loadSample(xmlFile, {}, "vehicle.closeDoorSound", "sounds/tuer_zu.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenDoorR = Utils.loadSample(xmlFile, {}, "vehicle.openDoorSound", "sounds/tuer_auf.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorR = Utils.loadSample(xmlFile, {}, "vehicle.closeDoorSound", "sounds/tuer_zu.wav", self.baseDirectory, self.components[1].node);
	end;
	self.warningLight = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.fendt31xDisplay.warningLight#index"));
	self.warningLightT = 0;
	self.warningLightActive = false;
	self.zuendungLight = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.fendt31xDisplay.zuendungLight#index"));
	self.blinkerLight0 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.fendt31xDisplay.blinkerLight#index0"));
	self.blinkerLight1 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.fendt31xDisplay.blinkerLight#index1"));
	self.blinkerLight2 = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.fendt31xDisplay.blinkerLight#index2"));
	self.blinkerLightActive = false;
	self.mFlickeringS = 0;
	self.handbremsLight = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.fendt31xDisplay.handbremsLight#index"));
	self.warnBlinkLight = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.fendt31xDisplay.warnBlinkLight#index"));
	setVisibility(self.warningLight, false);
	setVisibility(self.zuendungLight, false);
	setVisibility(self.blinkerLight0, false);
	setVisibility(self.blinkerLight1, false);
	setVisibility(self.blinkerLight2, false);
	setVisibility(self.handbremsLight, false);
	setVisibility(self.warnBlinkLight, false);
	
	self.hasAttachedTrailers = 0;
end;
function fendt31xSeries:delete()
	if self.sampleStartKlack ~= nil then
		Utils.deleteSample(self.sampleStartKlack);
	end;
	if self.sampleOpenDoorL ~= nil then
		Utils.deleteSample(self.sampleOpenDoorL);
	end;
	if self.sampleOpenDoorR ~= nil then
		Utils.deleteSample(self.sampleOpenDoorR);
	end;
	if self.sampleCloseDoorL ~= nil then
		Utils.deleteSample(self.sampleCloseDoorL);
	end;
	if self.sampleCloseDoorR ~= nil then
		Utils.deleteSample(self.sampleCloseDoorR);
	end;
end;
function fendt31xSeries:mouseEvent(posX, posY, isDown, isUp, button)
end;
function fendt31xSeries:keyEvent(unicode, sym, modifier, isDown)
end;
function fendt31xSeries:update(dt)
	if self:getIsActive() and self.isClient then
		if self.isEntered then
			if not self.isMotorStarted and (self.manMotorStart ~= nil and self.manMotorStart.startCnt ~= nil and self.manMotorStart.startCnt == 1) then
				setVisibility(self.zuendungLight, true);
			else
				setVisibility(self.zuendungLight, false);
			end;
			if not self.isMotorStarted and (self.manMotorStart ~= nil and self.manMotorStart.startCnt ~= nil and self.manMotorStart.startCnt == 1) then
				self:setWarningLight(true, true, dt);
			elseif (self.driveControl ~= nil and self.driveControl.handBrake ~= nil and self.driveControl.handBrake.isActive ~= nil and self.driveControl.handBrake.isActive) and (self.isMotorStarted or (not self.isMotorStarted and self.manMotorStart ~= nil and self.manMotorStart.startCnt ~= nil and self.manMotorStart.startCnt == 1)) then
				self:setWarningLight(true, false, dt);
			else
				self:setWarningLight(false);
			end;
			if self:getIsAnimationPlaying("doorLeftSource") then
				if self.animations["doorLeftSource"].currentSpeed > 0 then
					if (not Utils.isSamplePlaying(self.sampleOpenDoorL, 1.5*dt) and not Utils.isSamplePlaying(self.sampleCloseDoorL, 1.5*dt)) and self:getIsActiveForSound() then
						Utils.playSample(self.sampleOpenDoorL,1,1,nil);
					end;
				elseif self.animations["doorLeftSource"].currentSpeed < 0 then
					if (not Utils.isSamplePlaying(self.sampleCloseDoorL, 1.5*dt) and not Utils.isSamplePlaying(self.sampleOpenDoorL, 1.5*dt)) and self:getIsActiveForSound() then
						Utils.playSample(self.sampleCloseDoorL,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("doorRightSource") then
				if self.animations["doorRightSource"].currentSpeed > 0 then
					if (not Utils.isSamplePlaying(self.sampleOpenDoorR, 1.5*dt) and not Utils.isSamplePlaying(self.sampleCloseDoorR, 1.5*dt)) and self:getIsActiveForSound() then
						Utils.playSample(self.sampleOpenDoorR,1,1,nil);
					end;
				elseif self.animations["doorRightSource"].currentSpeed < 0 then
					if (not Utils.isSamplePlaying(self.sampleCloseDoorR, 1.5*dt) and not Utils.isSamplePlaying(self.sampleOpenDoorR, 1.5*dt)) and self:getIsActiveForSound() then
						Utils.playSample(self.sampleCloseDoorR,1,1,nil);
					end;
				end;
			end;
		else
			self:setWarningLight(false);
		end;
		local mFlickering = math.floor((getShaderTimeSec()*7*2 + math.acos(-0.2)) / (math.pi*2));
		if mFlickering ~= self.mFlickeringS then
			self.blinkerLightActive = not self.blinkerLightActive;
			self.mFlickeringS = mFlickering;
		end;
		if table.getn(self.attachedImplements) > 0 or self.hasAttachedTrailers > 0 then
			self.hasAttachedTrailers = 0;
			for i=1, table.getn(self.attachedImplements) do  
				if #self.attachedImplements[i].object.turnSignals.left > 0 and #self.attachedImplements[i].object.turnSignals.right > 0 then 
					self.hasAttachedTrailers = self.hasAttachedTrailers + 1;
				end;
				if table.getn(self.attachedImplements[i].object.attachedImplements) > 0 then
					for r=1, table.getn(self.attachedImplements[i].object.attachedImplements) do
						if #self.attachedImplements[i].object.attachedImplements[r].object.turnSignals.left > 0 and #self.attachedImplements[i].object.attachedImplements[r].object.turnSignals.right > 0 then
							self.hasAttachedTrailers = self.hasAttachedTrailers + 1;
						end;
					end;
				end;
			end;
		end;
		if self.hasAttachedTrailers == 0 then
			setVisibility(self.blinkerLight0, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight1, false);
			setVisibility(self.blinkerLight2, false);
		elseif self.hasAttachedTrailers == 1 then
			setVisibility(self.blinkerLight0, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight1, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight2, false);
		elseif self.hasAttachedTrailers == 2 then
			setVisibility(self.blinkerLight0, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight1, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
			setVisibility(self.blinkerLight2, (self.blinkerLightActive and self.turnSignalState ~= Vehicle.TURNSIGNAL_OFF));
		end;
		if self.turnSignalState == Vehicle.TURNSIGNAL_HAZARD then
			setVisibility(self.warnBlinkLight, true);
		else
			setVisibility(self.warnBlinkLight, false);
		end;
		if (self.driveControl ~= nil and self.driveControl.handBrake ~= nil and self.driveControl.handBrake.isActive ~= nil and self.driveControl.handBrake.isActive) and (self.isMotorStarted or (not self.isMotorStarted and self.manMotorStart ~= nil and self.manMotorStart.startCnt ~= nil and self.manMotorStart.startCnt == 1)) then
			setVisibility(self.handbremsLight, true);
		else
			setVisibility(self.handbremsLight, false);
		end;
	end;
end;
function fendt31xSeries:setWarningLight(blinking, playSound, dt)
	if blinking then
		self.warningLightT = self.warningLightT + dt;
		if self.warningLightT >= 340 then
			self.warningLightActive = not self.warningLightActive;
			self.warningLightT = 0;
			if self.warningLightActive and self:getIsActiveForSound() and playSound then
				Utils.playSample(self.sampleStartKlack, 1,1,nil);
			end;
		end;
	else
		self.warningLightActive = false;
	end;
	if self.warningLightActive then
		setVisibility(self.warningLight, true);
	else
		setVisibility(self.warningLight, false);
	end;
end;
function fendt31xSeries:updateTick(dt)
end;
function fendt31xSeries:draw()	
end;